CertificationData class

Annotations
  • @JsonSerializable.new()

Constructors

CertificationData({String? pg, String? merchantUid, String? company, String? carrier, String? name, String? phone, int? minAge, bool? popup, String? mRedirectUrl})
CertificationData.fromJson(Map<String, dynamic> json)
factory

Properties

carrier ↔ String?
getter/setter pair
company ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
merchantUid ↔ String?
getter/setter pair
minAge ↔ int?
getter/setter pair
mRedirectUrl ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
pg ↔ String?
getter/setter pair
phone ↔ String?
getter/setter pair
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited