BillingKeyMethod enum

빌링키 발급 수단

Inheritance
Available extensions

Values

CARD → const BillingKeyMethod

카드

const BillingKeyMethod('CARD')
MOBILE → const BillingKeyMethod

휴대전화

const BillingKeyMethod('MOBILE')
EASY_PAY → const BillingKeyMethod

간편결제

const BillingKeyMethod('EASY_PAY')
PAYPAL → const BillingKeyMethod

페이팔(RT)

const BillingKeyMethod('PAYPAL')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BillingKeyMethod>
A constant List of the values in this enum, in order of their declaration.