KsnetPaymentBypass class

KSNET bypass 파라미터

Constructors

KsnetPaymentBypass({KsnetSndQpayType? sndQpayType, bool? easyPayDirect})

Properties

easyPayDirect bool?
KSNET 간편결제 다이렉트 여부
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sndQpayType KsnetSndQpayType?
간편 결제 표시 구분
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited