TripleABypass class

Triple-A bypass 파라미터

Constructors

TripleABypass({String? payerPoi, int? shippingCost, int? shippingDiscount, int? taxCost})

Properties

hashCode int
The hash code for this object.
no setterinherited
payerPoi String?
결제자 신원 증명 정보
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingCost int?
배송비
final
shippingDiscount int?
배송비 할인 금액
final
taxCost int?
세금
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited