Country enum

국가

ISO 3166-1 alpha-2 코드입니다.

Inheritance
Available extensions

Values

AF → const Country

Afghanistan

const Country('AF')
AX → const Country

Åland Islands

const Country('AX')
AL → const Country

Albania

const Country('AL')
DZ → const Country

Algeria

const Country('DZ')
AS → const Country

American Samoa

const Country('AS')

Andorra

const Country('AD')
AO → const Country

Angola

const Country('AO')
AI → const Country

Anguilla

const Country('AI')
AQ → const Country

Antarctica

const Country('AQ')
AG → const Country

Antigua and Barbuda

const Country('AG')
AR → const Country

Argentina

const Country('AR')
AM → const Country

Armenia

const Country('AM')
AW → const Country

Aruba

const Country('AW')
AU → const Country

Australia

const Country('AU')
AT → const Country

Austria

const Country('AT')
AZ → const Country

Azerbaijan

const Country('AZ')
BH → const Country

Bahrain

const Country('BH')
BS → const Country

Bahamas

const Country('BS')
BD → const Country

Bangladesh

const Country('BD')
BB → const Country

Barbados

const Country('BB')
BY → const Country

Belarus

const Country('BY')
BE → const Country

Belgium

const Country('BE')
BZ → const Country

Belize

const Country('BZ')
BJ → const Country

Benin

const Country('BJ')
BM → const Country

Bermuda

const Country('BM')
BT → const Country

Bhutan

const Country('BT')
BO → const Country

Bolivia, Plurinational State of

const Country('BO')
BQ → const Country

Bonaire, Sint Eustatius and Saba

const Country('BQ')
BA → const Country

Bosnia and Herzegovina

const Country('BA')
BW → const Country

Botswana

const Country('BW')
BV → const Country

Bouvet Island

const Country('BV')
BR → const Country

Brazil

const Country('BR')
IO → const Country

British Indian Ocean Territory

const Country('IO')
BN → const Country

Brunei Darussalam

const Country('BN')
BG → const Country

Bulgaria

const Country('BG')
BF → const Country

Burkina Faso

const Country('BF')
BI → const Country

Burundi

const Country('BI')
KH → const Country

Cambodia

const Country('KH')
CM → const Country

Cameroon

const Country('CM')
CA → const Country

Canada

const Country('CA')
CV → const Country

Cape Verde

const Country('CV')
KY → const Country

Cayman Islands

const Country('KY')
CF → const Country

Central African Republic

const Country('CF')
TD → const Country

Chad

const Country('TD')
CL → const Country

Chile

const Country('CL')
CN → const Country

China

const Country('CN')
CX → const Country

Christmas Island

const Country('CX')
CC → const Country

Cocos (Keeling) Islands

const Country('CC')
CO → const Country

Colombia

const Country('CO')
KM → const Country

Comoros

const Country('KM')
CG → const Country

Congo

const Country('CG')
CD → const Country

Congo, the Democratic Republic of the

const Country('CD')
CK → const Country

Cook Islands

const Country('CK')
CR → const Country

Costa Rica

const Country('CR')
CI → const Country

Côte d'Ivoire

const Country('CI')
HR → const Country

Croatia

const Country('HR')
CU → const Country

Cuba

const Country('CU')
CW → const Country

Curaçao

const Country('CW')
CY → const Country

Cyprus

const Country('CY')
CZ → const Country

Czech Republic

const Country('CZ')
DK → const Country

Denmark

const Country('DK')
DJ → const Country

Djibouti

const Country('DJ')
DM → const Country

Dominica

const Country('DM')
DO → const Country

Dominican Republic

const Country('DO')
EC → const Country

Ecuador

const Country('EC')
EG → const Country

Egypt

const Country('EG')
SV → const Country

El Salvador

const Country('SV')
GQ → const Country

Equatorial Guinea

const Country('GQ')
ER → const Country

Eritrea

const Country('ER')
EE → const Country

Estonia

const Country('EE')
ET → const Country

Ethiopia

const Country('ET')
FK → const Country

Falkland Islands (Malvinas)

const Country('FK')
FO → const Country

Faroe Islands

const Country('FO')
FJ → const Country

Fiji

const Country('FJ')
FI → const Country

Finland

const Country('FI')
FR → const Country

France

const Country('FR')
GF → const Country

French Guiana

const Country('GF')
PF → const Country

French Polynesia

const Country('PF')
TF → const Country

French Southern Territories

const Country('TF')
GA → const Country

Gabon

const Country('GA')
GM → const Country

Gambia

const Country('GM')
GE → const Country

Georgia

const Country('GE')
DE → const Country

Germany

const Country('DE')
GH → const Country

Ghana

const Country('GH')
GI → const Country

Gibraltar

const Country('GI')
GR → const Country

Greece

const Country('GR')
GL → const Country

Greenland

const Country('GL')
GD → const Country

Grenada

const Country('GD')
GP → const Country

Guadeloupe

const Country('GP')
GU → const Country

Guam

const Country('GU')
GT → const Country

Guatemala

const Country('GT')
GG → const Country

Guernsey

const Country('GG')
GN → const Country

Guinea

const Country('GN')
GW → const Country

Guinea-Bissau

const Country('GW')
GY → const Country

Guyana

const Country('GY')
HT → const Country

Haiti

const Country('HT')
HM → const Country

Heard Island and McDonald Islands

const Country('HM')
VA → const Country

Holy See (Vatican City State)

const Country('VA')
HN → const Country

Honduras

const Country('HN')
HK → const Country

Hong Kong

const Country('HK')
HU → const Country

Hungary

const Country('HU')
IS → const Country

Iceland

const Country('IS')
IN → const Country

India

const Country('IN')
ID → const Country

Indonesia

const Country('ID')
IR → const Country

Iran, Islamic Republic of

const Country('IR')
IQ → const Country

Iraq

const Country('IQ')
IE → const Country

Ireland

const Country('IE')
IM → const Country

Isle of Man

const Country('IM')
IL → const Country

Israel

const Country('IL')
IT → const Country

Italy

const Country('IT')
JM → const Country

Jamaica

const Country('JM')
JP → const Country

Japan

const Country('JP')
JE → const Country

Jersey

const Country('JE')
JO → const Country

Jordan

const Country('JO')
KZ → const Country

Kazakhstan

const Country('KZ')
KE → const Country

Kenya

const Country('KE')
KI → const Country

Kiribati

const Country('KI')
KP → const Country

Korea, Democratic People's Republic of

const Country('KP')
KR → const Country

Korea, Republic of

const Country('KR')
KW → const Country

Kuwait

const Country('KW')
KG → const Country

Kyrgyzstan

const Country('KG')
LA → const Country

Lao People's Democratic Republic

const Country('LA')
LV → const Country

Latvia

const Country('LV')
LB → const Country

Lebanon

const Country('LB')
LS → const Country

Lesotho

const Country('LS')
LR → const Country

Liberia

const Country('LR')
LY → const Country

Libya

const Country('LY')
LI → const Country

Liechtenstein

const Country('LI')
LT → const Country

Lithuania

const Country('LT')
LU → const Country

Luxembourg

const Country('LU')
MO → const Country

Macao

const Country('MO')
MK → const Country

Macedonia, the Former Yugoslav Republic of

const Country('MK')
MG → const Country

Madagascar

const Country('MG')
MW → const Country

Malawi

const Country('MW')
MY → const Country

Malaysia

const Country('MY')
MV → const Country

Maldives

const Country('MV')
ML → const Country

Mali

const Country('ML')
MT → const Country

Malta

const Country('MT')
MH → const Country

Marshall Islands

const Country('MH')
MQ → const Country

Martinique

const Country('MQ')
MR → const Country

Mauritania

const Country('MR')
MU → const Country

Mauritius

const Country('MU')
YT → const Country

Mayotte

const Country('YT')
MX → const Country

Mexico

const Country('MX')
FM → const Country

Micronesia, Federated States of

const Country('FM')
MD → const Country

Moldova, Republic of

const Country('MD')
MC → const Country

Monaco

const Country('MC')
MN → const Country

Mongolia

const Country('MN')
ME → const Country

Montenegro

const Country('ME')
MS → const Country

Montserrat

const Country('MS')
MA → const Country

Morocco

const Country('MA')
MZ → const Country

Mozambique

const Country('MZ')
MM → const Country

Myanmar

const Country('MM')
NA → const Country

Namibia

const Country('NA')
NR → const Country

Nauru

const Country('NR')
NP → const Country

Nepal

const Country('NP')
NL → const Country

Netherlands

const Country('NL')
NC → const Country

New Caledonia

const Country('NC')
NZ → const Country

New Zealand

const Country('NZ')
NI → const Country

Nicaragua

const Country('NI')
NE → const Country

Niger

const Country('NE')
NG → const Country

Nigeria

const Country('NG')
NU → const Country

Niue

const Country('NU')
NF → const Country

Norfolk Island

const Country('NF')
MP → const Country

Northern Mariana Islands

const Country('MP')
NO → const Country

Norway

const Country('NO')
OM → const Country

Oman

const Country('OM')
PK → const Country

Pakistan

const Country('PK')
PW → const Country

Palau

const Country('PW')
PS → const Country

Palestine, State of

const Country('PS')
PA → const Country

Panama

const Country('PA')
PG → const Country

Papua New Guinea

const Country('PG')
PY → const Country

Paraguay

const Country('PY')
PE → const Country

Peru

const Country('PE')
PH → const Country

Philippines

const Country('PH')
PN → const Country

Pitcairn

const Country('PN')
PL → const Country

Poland

const Country('PL')
PT → const Country

Portugal

const Country('PT')
PR → const Country

Puerto Rico

const Country('PR')
QA → const Country

Qatar

const Country('QA')
RE → const Country

Réunion

const Country('RE')
RO → const Country

Romania

const Country('RO')
RU → const Country

Russian Federation

const Country('RU')
RW → const Country

Rwanda

const Country('RW')
BL → const Country

Saint Barthélemy

const Country('BL')
SH → const Country

Saint Helena, Ascension and Tristan da Cunha

const Country('SH')
KN → const Country

Saint Kitts and Nevis

const Country('KN')
LC → const Country

Saint Lucia

const Country('LC')
MF → const Country

Saint Martin (French part)

const Country('MF')
PM → const Country

Saint Pierre and Miquelon

const Country('PM')
VC → const Country

Saint Vincent and the Grenadines

const Country('VC')
WS → const Country

Samoa

const Country('WS')
SM → const Country

San Marino

const Country('SM')
ST → const Country

Sao Tome and Principe

const Country('ST')
SA → const Country

Saudi Arabia

const Country('SA')
SN → const Country

Senegal

const Country('SN')
RS → const Country

Serbia

const Country('RS')
SC → const Country

Seychelles

const Country('SC')
SL → const Country

Sierra Leone

const Country('SL')
SG → const Country

Singapore

const Country('SG')
SX → const Country

Sint Maarten (Dutch part)

const Country('SX')
SK → const Country

Slovakia

const Country('SK')
SI → const Country

Slovenia

const Country('SI')
SB → const Country

Solomon Islands

const Country('SB')
SO → const Country

Somalia

const Country('SO')
ZA → const Country

South Africa

const Country('ZA')
GS → const Country

South Georgia and the South Sandwich Islands

const Country('GS')
SS → const Country

South Sudan

const Country('SS')
ES → const Country

Spain

const Country('ES')
LK → const Country

Sri Lanka

const Country('LK')
SD → const Country

Sudan

const Country('SD')
SR → const Country

Suriname

const Country('SR')
SJ → const Country

Svalbard and Jan Mayen

const Country('SJ')
SZ → const Country

Swaziland

const Country('SZ')
SE → const Country

Sweden

const Country('SE')
CH → const Country

Switzerland

const Country('CH')
SY → const Country

Syrian Arab Republic

const Country('SY')
TW → const Country

Taiwan, Province of China

const Country('TW')
TJ → const Country

Tajikistan

const Country('TJ')
TZ → const Country

Tanzania, United Republic of

const Country('TZ')
TH → const Country

Thailand

const Country('TH')
TL → const Country

Timor-Leste

const Country('TL')
TG → const Country

Togo

const Country('TG')
TK → const Country

Tokelau

const Country('TK')
TO → const Country

Tonga

const Country('TO')
TT → const Country

Trinidad and Tobago

const Country('TT')
TN → const Country

Tunisia

const Country('TN')
TR → const Country

Turkey

const Country('TR')
TM → const Country

Turkmenistan

const Country('TM')
TC → const Country

Turks and Caicos Islands

const Country('TC')
TV → const Country

Tuvalu

const Country('TV')
UG → const Country

Uganda

const Country('UG')
UA → const Country

Ukraine

const Country('UA')
AE → const Country

United Arab Emirates

const Country('AE')
GB → const Country

United Kingdom

const Country('GB')
US → const Country

United States

const Country('US')
UM → const Country

United States Minor Outlying Islands

const Country('UM')
UY → const Country

Uruguay

const Country('UY')
UZ → const Country

Uzbekistan

const Country('UZ')
VU → const Country

Vanuatu

const Country('VU')
VE → const Country

Venezuela, Bolivarian Republic of

const Country('VE')
VN → const Country

Viet Nam

const Country('VN')
VG → const Country

Virgin Islands, British

const Country('VG')
VI → const Country

Virgin Islands, U.S.

const Country('VI')
WF → const Country

Wallis and Futuna

const Country('WF')
EH → const Country

Western Sahara

const Country('EH')
YE → const Country

Yemen

const Country('YE')
ZM → const Country

Zambia

const Country('ZM')
ZW → const Country

Zimbabwe

const Country('ZW')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Country>
A constant List of the values in this enum, in order of their declaration.