Currency enum

화폐

ISO 4217 화폐 코드

대한민국 원, 일본 엔이 아닌 화폐를 사용할 때에는 금액을 minor unit 단위로 입력해야 함에 유의하세요.

Inheritance
Available extensions

Values

KRW → const Currency

South Korean won

const Currency('KRW')
USD → const Currency

United States dollar

const Currency('USD')
EUR → const Currency

Euro

const Currency('EUR')
JPY → const Currency

Japanese yen

const Currency('JPY')
CNY → const Currency

Chinese yuan

const Currency('CNY')
VND → const Currency

Vietnamese dong

const Currency('VND')
THB → const Currency

Thai baht

const Currency('THB')
SGD → const Currency

Singapore dollar

const Currency('SGD')
AUD → const Currency

Australian dollar

const Currency('AUD')
HKD → const Currency

Hong Kong dollar

const Currency('HKD')
AED → const Currency

United Arab Emirates dirham

const Currency('AED')
AFN → const Currency

Afghan afghani

const Currency('AFN')
ALL → const Currency

Albanian lek

const Currency('ALL')
AMD → const Currency

Armenian dram

const Currency('AMD')
ANG → const Currency

Netherlands Antillean guilder

const Currency('ANG')
AOA → const Currency

Angolan kwanza

const Currency('AOA')
ARS → const Currency

Argentine peso

const Currency('ARS')
AWG → const Currency

Aruban florin

const Currency('AWG')
AZN → const Currency

Azerbaijani manat

const Currency('AZN')
BAM → const Currency

Bosnia and Herzegovina convertible mark

const Currency('BAM')
BBD → const Currency

Barbadian dollar

const Currency('BBD')
BDT → const Currency

Bangladeshi taka

const Currency('BDT')
BGN → const Currency

Bulgarian lev

const Currency('BGN')
BMD → const Currency

Bermudian dollar

const Currency('BMD')
BND → const Currency

Brunei dollar

const Currency('BND')
BOB → const Currency

Boliviano

const Currency('BOB')
BOV → const Currency

Bolivian Mvdol

const Currency('BOV')
BRL → const Currency

Brazilian real

const Currency('BRL')
BSD → const Currency

Bahamian dollar

const Currency('BSD')
BWP → const Currency

Botswana pula

const Currency('BWP')
BYN → const Currency

Belarusian ruble

const Currency('BYN')
BZD → const Currency

Belize dollar

const Currency('BZD')
CAD → const Currency

Canadian dollar

const Currency('CAD')
CDF → const Currency

Congolese franc

const Currency('CDF')
CHE → const Currency

WIR euro

const Currency('CHE')
CHF → const Currency

Swiss franc

const Currency('CHF')
CHW → const Currency

WIR franc

const Currency('CHW')
CLF → const Currency

Chilean unit of account (UF)

const Currency('CLF')
CLP → const Currency

Chilean peso

const Currency('CLP')
COP → const Currency

Colombian peso

const Currency('COP')
COU → const Currency

Unidad de Valor Real

const Currency('COU')
CRC → const Currency

Costa Rican colon

const Currency('CRC')
CUC → const Currency

Cuban convertible peso

const Currency('CUC')
CUP → const Currency

Cuban peso

const Currency('CUP')
CVE → const Currency

Cape Verdean escudo

const Currency('CVE')
CZK → const Currency

Czech koruna

const Currency('CZK')
DJF → const Currency

Djiboutian franc

const Currency('DJF')
DKK → const Currency

Danish krone

const Currency('DKK')
DOP → const Currency

Dominican peso

const Currency('DOP')
DZD → const Currency

Algerian dinar

const Currency('DZD')
EGP → const Currency

Egyptian pound

const Currency('EGP')
ERN → const Currency

Eritrean nakfa

const Currency('ERN')
ETB → const Currency

Ethiopian birr

const Currency('ETB')
FJD → const Currency

Fiji dollar

const Currency('FJD')
FKP → const Currency

Falkland Islands pound

const Currency('FKP')
GBP → const Currency

Pound sterling

const Currency('GBP')
GEL → const Currency

Georgian lari

const Currency('GEL')
GHS → const Currency

Ghanaian cedi

const Currency('GHS')
GIP → const Currency

Gibraltar pound

const Currency('GIP')
GMD → const Currency

Gambian dalasi

const Currency('GMD')
GNF → const Currency

Guinean franc

const Currency('GNF')
GTQ → const Currency

Guatemalan quetzal

const Currency('GTQ')
GYD → const Currency

Guyanese dollar

const Currency('GYD')
HNL → const Currency

Honduran lempira

const Currency('HNL')
HRK → const Currency

Croatian kuna

const Currency('HRK')
HTG → const Currency

Haitian gourde

const Currency('HTG')
HUF → const Currency

Hungarian forint

const Currency('HUF')
IDR → const Currency

Indonesian rupiah

const Currency('IDR')
ILS → const Currency

Israeli new shekel

const Currency('ILS')
INR → const Currency

Indian rupee

const Currency('INR')
IQD → const Currency

Iraqi dinar

const Currency('IQD')
IRR → const Currency

Iranian rial

const Currency('IRR')
ISK → const Currency

Icelandic króna

const Currency('ISK')
JMD → const Currency

Jamaican dollar

const Currency('JMD')
JOD → const Currency

Jordanian dinar

const Currency('JOD')
KES → const Currency

Kenyan shilling

const Currency('KES')
KGS → const Currency

Kyrgyzstani som

const Currency('KGS')
KHR → const Currency

Cambodian riel

const Currency('KHR')
KMF → const Currency

Comoro franc

const Currency('KMF')
KPW → const Currency

North Korean won

const Currency('KPW')
KWD → const Currency

Kuwaiti dinar

const Currency('KWD')
KYD → const Currency

Cayman Islands dollar

const Currency('KYD')
KZT → const Currency

Kazakhstani tenge

const Currency('KZT')
LAK → const Currency

Lao kip

const Currency('LAK')
LBP → const Currency

Lebanese pound

const Currency('LBP')
LKR → const Currency

Sri Lankan rupee

const Currency('LKR')
LRD → const Currency

Liberian dollar

const Currency('LRD')
LSL → const Currency

Lesotho loti

const Currency('LSL')
LYD → const Currency

Libyan dinar

const Currency('LYD')
MAD → const Currency

Moroccan dirham

const Currency('MAD')
MDL → const Currency

Moldovan leu

const Currency('MDL')
MGA → const Currency

Malagasy ariary

const Currency('MGA')
MKD → const Currency

Macedonian denar

const Currency('MKD')
MMK → const Currency

Myanmar kyat

const Currency('MMK')
MNT → const Currency

Mongolian tögrög

const Currency('MNT')
MOP → const Currency

Macanese pataca

const Currency('MOP')
MRU → const Currency

Mauritanian ouguiya

const Currency('MRU')
MUR → const Currency

Mauritian rupee

const Currency('MUR')
MVR → const Currency

Maldivian rufiyaa

const Currency('MVR')
MWK → const Currency

Malawian kwacha

const Currency('MWK')
MXN → const Currency

Mexican peso

const Currency('MXN')
MXV → const Currency

Mexican Unidad de Inversion

const Currency('MXV')
MZN → const Currency

Mozambican metical

const Currency('MZN')
NAD → const Currency

Namibian dollar

const Currency('NAD')
NGN → const Currency

Nigerian naira

const Currency('NGN')
NIO → const Currency

Nicaraguan córdoba

const Currency('NIO')
NOK → const Currency

Norwegian krone

const Currency('NOK')
NPR → const Currency

Nepalese rupee

const Currency('NPR')
NZD → const Currency

New Zealand dollar

const Currency('NZD')
OMR → const Currency

Omani rial

const Currency('OMR')
PAB → const Currency

Panamanian balboa

const Currency('PAB')
PEN → const Currency

Peruvian sol

const Currency('PEN')
PGK → const Currency

Papua New Guinean kina

const Currency('PGK')
PHP → const Currency

Philippine peso

const Currency('PHP')
PKR → const Currency

Pakistani rupee

const Currency('PKR')
PLN → const Currency

Polish złoty

const Currency('PLN')
PYG → const Currency

Paraguayan guaraní

const Currency('PYG')
QAR → const Currency

Qatari riyal

const Currency('QAR')
RON → const Currency

Romanian leu

const Currency('RON')
RSD → const Currency

Serbian dinar

const Currency('RSD')
RUB → const Currency

Russian ruble

const Currency('RUB')
RWF → const Currency

Rwandan franc

const Currency('RWF')
SAR → const Currency

Saudi riyal

const Currency('SAR')
SBD → const Currency

Solomon Islands dollar

const Currency('SBD')
SCR → const Currency

Seychelles rupee

const Currency('SCR')
SDG → const Currency

Sudanese pound

const Currency('SDG')
SEK → const Currency

Swedish krona

const Currency('SEK')
SHP → const Currency

Saint Helena pound

const Currency('SHP')
SLE → const Currency

Sierra Leonean leone (new leone)

const Currency('SLE')
SLL → const Currency

Sierra Leonean leone (old leone)

const Currency('SLL')
SOS → const Currency

Somali shilling

const Currency('SOS')
SRD → const Currency

Surinamese dollar

const Currency('SRD')
SSP → const Currency

South Sudanese pound

const Currency('SSP')
STN → const Currency

São Tomé and Príncipe dobra

const Currency('STN')
SVC → const Currency

Salvadoran colón

const Currency('SVC')
SYP → const Currency

Syrian pound

const Currency('SYP')
SZL → const Currency

Swazi lilangeni

const Currency('SZL')
TJS → const Currency

Tajikistani somoni

const Currency('TJS')
TMT → const Currency

Turkmenistan manat

const Currency('TMT')
TND → const Currency

Tunisian dinar

const Currency('TND')
TOP → const Currency

Tongan paʻanga

const Currency('TOP')
TRY → const Currency

Turkish lira

const Currency('TRY')
TTD → const Currency

Trinidad and Tobago dollar

const Currency('TTD')
TWD → const Currency

New Taiwan dollar

const Currency('TWD')
TZS → const Currency

Tanzanian shilling

const Currency('TZS')
UAH → const Currency

Ukrainian hryvnia

const Currency('UAH')
UGX → const Currency

Ugandan shilling

const Currency('UGX')
USN → const Currency

United States dollar (next day)

const Currency('USN')
UYI → const Currency

Uruguay Peso en Unidades Indexadas

const Currency('UYI')
UYU → const Currency

Uruguayan peso

const Currency('UYU')
UYW → const Currency

Unidad previsional

const Currency('UYW')
UZS → const Currency

Uzbekistan som

const Currency('UZS')
VED → const Currency

Venezuelan bolívar digital

const Currency('VED')
VES → const Currency

Venezuelan bolívar soberano

const Currency('VES')
VUV → const Currency

Vanuatu vatu

const Currency('VUV')
WST → const Currency

Samoan tala

const Currency('WST')
XAF → const Currency

CFA franc BEAC

const Currency('XAF')
XAG → const Currency

Silver (one troy ounce)

const Currency('XAG')
XAU → const Currency

Gold (one troy ounce)

const Currency('XAU')
XBA → const Currency

European Composite Unit

const Currency('XBA')
XBB → const Currency

European Monetary Unit

const Currency('XBB')
XBC → const Currency

European Unit of Account 9

const Currency('XBC')
XBD → const Currency

European Unit of Account 17

const Currency('XBD')
XCD → const Currency

East Caribbean dollar

const Currency('XCD')
XDR → const Currency

Special drawing rights

const Currency('XDR')
XOF → const Currency

CFA franc BCEAO

const Currency('XOF')
XPD → const Currency

Palladium (one troy ounce)

const Currency('XPD')
XPF → const Currency

CFP franc

const Currency('XPF')
XPT → const Currency

Platinum (one troy ounce)

const Currency('XPT')
XSU → const Currency

SUCRE

const Currency('XSU')
XTS → const Currency

Code reserved for testing

const Currency('XTS')
XUA → const Currency

ADB Unit of Account

const Currency('XUA')
XXX → const Currency

No currency

const Currency('XXX')
YER → const Currency

Yemeni rial

const Currency('YER')
ZAR → const Currency

South African rand

const Currency('ZAR')
ZMW → const Currency

Zambian kwacha

const Currency('ZMW')
ZWL → const Currency

Zimbabwean dollar

const Currency('ZWL')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Currency>
A constant List of the values in this enum, in order of their declaration.