FreeInstallmentPlan class

무이자 할부 설정

고객사가 부담하는 무이자 할부 설정입니다. 이자 수수료를 가맹점이 부담하여 구매자에게 무이자로 할부를 제공합니다.

사용 예시

삼성카드에 대해 2, 3개월 무이자 할부 적용, 신한카드에 대해 2, 3, 4, 5, 6개월 무이자 할부 적용

freeInstallmentPlans: [
{
cardCompany: 'CARD_COMPANY_SAMSUNG',
months: [2, 3]
},
{
cardCompany: 'CARD_COMPANY_SHINHAN',
months: [2, 3, 4, 5, 6]
}
]

주의사항

  • 무이자 할부 수수료는 가맹점이 부담합니다
  • PG사와의 계약에 따라 무이자 할부 제공 가능 여부가 결정됩니다
  • 카드사별로 최소 결제 금액 제한이 있을 수 있습니다 (일반적으로 5만원 이상)
  • 일부 카드사는 특정 개월수에 대해서만 무이자 할부를 허용할 수 있습니다

Constructors

FreeInstallmentPlan({required CardCompany cardCompany, required List<int> months})

Properties

cardCompany CardCompany
카드 결제시 사용되는 카드사 코드
final
hashCode int
The hash code for this object.
no setterinherited
months List<int>
무이자 할부를 제공하는 개월 수
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited