Installment class

할부 설정

신용카드 결제 시 할부 관련 설정을 제어합니다.

사용 예시

3개월 고정 할부

installment: {
monthOption: {
fixedMonth: 3
}
}

2~6개월 할부 선택

installment: {
monthOption: {
availableMonthList: [2, 3, 4, 5, 6]
}
}

무이자 할부 설정 (삼성카드 2,3개월)

installment: {
freeInstallmentPlans: [{
cardCompany: 'CARD_COMPANY_SAMSUNG',
months: [2, 3]
}]
}

주의사항

  • 일반적으로 5만원 이상부터 할부가 가능합니다
  • 1개월 할부는 일시불과 동일하게 처리됩니다
  • 카드 다이렉트 호출 시 고정 할부만 가능한 PG사가 있습니다
  • 무이자 할부는 가맹점이 수수료를 부담하는 방식입니다

Constructors

Installment({List<FreeInstallmentPlan>? freeInstallmentPlans, InstallmentMonthOption? monthOption})

Properties

freeInstallmentPlans List<FreeInstallmentPlan>?
무이자 할부 설정
final
hashCode int
The hash code for this object.
no setterinherited
monthOption InstallmentMonthOption?
할부 개월 수 설정
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited