InstallmentMonthOption class sealed

할부 개월 수 설정

할부 결제 시 할부 개월 수를 설정할 수 있습니다.

fixedMonthavailableMonthList 중 하나만 제공해주세요.

  • fixedMonth: 고정 할부 개월 수
  • availableMonthList: 렌더링을 허용 할 할부 개월 수 리스트

예1) 3개월 고정 할부 개월 수

monthOption: {
fixedMonth: 3
}

예2) 2, 3, 4, 5, 6개월 리스트 할부 개월 수

monthOption: {
availableMonthList: [2, 3, 4, 5, 6]
}
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited