Locale enum

UI 언어

KG이니시스, 스마트로, KSNET, 웰컴페이먼츠 (PC), 한국결제네트웍스, 엑심베이, Triple-A에서 설정 가능하며, PG마다 지원하는 언어 목록은 차이가 있습니다.

Inheritance
Available extensions

Values

KO_KR → const Locale

한국어

  • KG이니시스
  • 스마트로
  • KSNET
  • 웰컴페이먼츠 (PC)
  • 한국결제네트웍스
  • 엑심베이
const Locale('KO_KR')
EN_US → const Locale

영어

  • KG이니시스
  • 스마트로
  • KSNET
  • 웰컴페이먼츠 (PC)
  • 한국결제네트웍스
  • 엑심베이
  • Triple-A
const Locale('EN_US')
ZH_CN → const Locale

중국어 (중국 본토)

  • KG이니시스 (PC)
  • 웰컴페이먼츠 (PC)
  • 엑심베이
  • Triple-A
const Locale('ZH_CN')
ZH_TW → const Locale

중국어 (대만)

  • 엑심베이
  • Triple-A
const Locale('ZH_TW')
JA_JP → const Locale

일본어

  • 엑심베이
  • Triple-A
const Locale('JA_JP')
RU_RU → const Locale

러시아어

  • 엑심베이
  • Triple-A
const Locale('RU_RU')
TH_TH → const Locale

타이어

  • 엑심베이
const Locale('TH_TH')
VI_VN → const Locale

베트남어

  • 엑심베이
const Locale('VI_VN')
ID_ID → const Locale

인도네시아어

  • Triple-A
const Locale('ID_ID')
FR_FR → const Locale

프랑스어

  • Triple-A
const Locale('FR_FR')
NL_NL → const Locale

네덜란드어

  • Triple-A
const Locale('NL_NL')
ES_ES → const Locale

에스파냐어

  • Triple-A
const Locale('ES_ES')
PT_PT → const Locale

포르투갈어

  • Triple-A
const Locale('PT_PT')
DE_DE → const Locale

독일어

  • Triple-A
const Locale('DE_DE')
IT_IT → const Locale

이탈리아어

  • Triple-A
const Locale('IT_IT')
PL_PL → const Locale

폴란드어

  • Triple-A
const Locale('PL_PL')
AR_001 → const Locale

현대 표준 아랍어

  • Triple-A
const Locale('AR_001')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Locale>
A constant List of the values in this enum, in order of their declaration.