OfferPeriod class sealed
서비스 제공 기간
range와 interval 중 하나를 입력해주세요.
- range: 제공 기간 범위
- interval: 제공 기간 주기
예1) 2023년 1월 1일 00시 00분 00초(KST) ~
range: {
from: '2023-01-01T00:00:00+09:00'
}
예2) ~ 2023년 1월 1일 00시 00분 00초(KST)
range: {
to: '2023-01-01T00:00:00+09:00'
}
예3) 2023년 1월 1일 00시 00분 00초(KST) ~ 2023년 12월 31일 23시 59분 59초(KST)
range: {
from: '2023-12-31T23:59:59+09:00'
to: '2023-01-01T00:00:00+09:00'
}
예4) 30일 주기
interval: '30d'
예5) 6개월 주기
interval: '6m'
예6) 1년 주기
interval: '1y'
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited