OfferPeriodInterval class

제공 주기

제공 주기 (${number}d | ${number}m | ${number}y 형태로 입력할 수 있습니다.)

Inheritance

Constructors

OfferPeriodInterval(String? interval)

Properties

hashCode int
The hash code for this object.
no setterinherited
interval String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited