OfferPeriodRangeFrom class

시작 시점만 있는 기간 범위

Constructors

OfferPeriodRangeFrom({required String from})

Properties

from String
시작 시점
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toOfferPeriodRange() OfferPeriodRange
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited