OfferPeriodRangeTo class

종료 지점만 있는 기간 범위

Constructors

OfferPeriodRangeTo({required String to})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to String
종료 지점
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toOfferPeriodRange() OfferPeriodRange
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited