Popup class

팝업 관련 필드

UI가 팝업 창으로 열릴 때 적용되는 속성입니다.

Constructors

Popup({bool? center})

Properties

center bool?
팝업 정중앙 표시 true로 설정하면 팝업이 브라우저 화면의 정중앙에 표시됩니다. 결제사 및 환경에 따라 적용되지 않을 수 있습니다.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited