IdentityVerificationRequest class

Constructors

IdentityVerificationRequest({required String storeId, required String identityVerificationId, String? channelKey, Customer? customer, WindowTypes? windowType, bool? forceRedirect, String? customData, IdentityVerificationBypass? bypass, Popup? popup, Iframe? iframe})

Properties

bypass IdentityVerificationBypass?
PG사 본인인증 창 호출 시 PG사로 그대로 bypass할 값들의 모음
final
channelKey String?
채널 키
final
customData String?
본인인증 정보와 함께 관리하고 싶은 고객사 커스텀 JSON 데이터
final
customer Customer?
final
forceRedirect bool?
결과 리턴 방식을 리디렉션으로 강제
final
hashCode int
The hash code for this object.
no setterinherited
identityVerificationId String
본인인증 건 ID
final
iframe Iframe?
결제창이 iframe 방식일 경우 결제창에 적용할 속성
final
팝업 관련 필드
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeId String
상점 아이디
final
windowType WindowTypes?
환경 별 제공되는 결제/본인인증 창 유형
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited