IssueBillingKeyRequest class

Constructors

IssueBillingKeyRequest({int? displayAmount, Currency? currency, required String storeId, String? channelKey, required BillingKeyMethod billingKeyMethod, String? issueName, String? issueId, Customer? customer, WindowTypes? windowType, bool? forceRedirect, Locale? locale, Object? customData, OfferPeriod? offerPeriod, required String appScheme, List<String>? noticeUrls, ProductType? productType, IssueBillingKeyBypass? bypass, Popup? popup, Iframe? iframe, IssueBillingKeyRequestUnionCard? card, IssueBillingKeyRequestUnionMobile? mobile, IssueBillingKeyRequestUnionEasyPay? easyPay, IssueBillingKeyRequestUnionPaypal? paypal})

Properties

appScheme String
앱 URL Scheme
final
billingKeyMethod BillingKeyMethod
빌링키 발급 수단
final
bypass IssueBillingKeyBypass?
final
card IssueBillingKeyRequestUnionCard?
final
channelKey String?
채널 키
final
currency Currency?
화폐
final
customData Object?
빌링키 발급 정보와 함께 관리하고 싶은 고객사 커스텀 JSON 데이터
final
customer Customer?
final
displayAmount int?
빌링키 발급 창에 디스플레이 용으로 띄우는 금액
final
easyPay IssueBillingKeyRequestUnionEasyPay?
final
forceRedirect bool?
결과 리턴 방식을 리디렉션으로 강제
final
hashCode int
The hash code for this object.
no setterinherited
iframe Iframe?
결제창이 iframe 방식일 경우 결제창에 적용할 속성
final
issueId String?
빌링키 발급 주문 고유 번호
final
issueName String?
빌링키 발급 주문 명
final
locale Locale?
UI 언어
final
mobile IssueBillingKeyRequestUnionMobile?
final
noticeUrls List<String>?
웹훅 URL
final
offerPeriod OfferPeriod?
서비스 제공 기간
final
paypal IssueBillingKeyRequestUnionPaypal?
final
팝업 관련 필드
final
productType ProductType?
상품 유형
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeId String
상점 아이디
final
windowType WindowTypes?
환경 별 제공되는 결제/본인인증 창 유형
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited