LoadPaymentUIRequest class

Constructors

LoadPaymentUIRequest({required PaymentUIType uiType, required String storeId, required String paymentId, required String orderName, required int totalAmount, required String channelKey, int? taxFreeAmount, int? vatAmount, Customer? customer, List<String>? noticeUrls, String? confirmUrl, required String appScheme, bool? isEscrow, List<Product>? products, bool? isCulturalExpense, required Currency currency, Locale? locale, Object? customData, OfferPeriod? offerPeriod, ProductType? productType, StoreDetails? storeDetails, LoadPaymentUIBypass? bypass, Country? country, Address? shippingAddress, String? promotionGroupId, List<String>? promotionIds})

Properties

appScheme String
앱 URL Scheme
final
bypass LoadPaymentUIBypass?
final
channelKey String
채널 키
final
confirmUrl String?
Confirm URL
final
country Country?
국가
final
currency Currency
화폐
final
customData Object?
결제 정보와 함께 관리하고 싶은 고객사 커스텀 JSON 데이터
final
customer Customer?
final
hashCode int
The hash code for this object.
no setterinherited
isCulturalExpense bool?
문화비 지출 여부
final
isEscrow bool?
에스크로 결제 여부
final
locale Locale?
UI 언어
final
noticeUrls List<String>?
웹훅 URL
final
offerPeriod OfferPeriod?
서비스 제공 기간
final
orderName String
주문명
final
paymentId String
결제 ID
final
products List<Product>?
구매 상품 정보
final
productType ProductType?
상품 유형
final
promotionGroupId String?
프로모션 그룹 ID
final
promotionIds List<String>?
프로모션 ID 목록
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress Address?
주소 정보
final
storeDetails StoreDetails?
상점 정보
final
storeId String
상점 아이디
final
taxFreeAmount int?
면세 금액
final
totalAmount int
결제 금액
final
uiType PaymentUIType
final
vatAmount int?
부가세 금액
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited