PaymentRequestUnionGiftCertificate class

상품권 결제 설정

Constructors

PaymentRequestUnionGiftCertificate({GiftCertificateType? giftCertificateType})

Properties

giftCertificateType GiftCertificateType?
상품권 종류
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited