PaymentRequestUnionMobile class

휴대전화 결제 설정

Constructors

PaymentRequestUnionMobile({Carrier? carrier, List<Carrier>? avaliableCarriers})

Properties

avaliableCarriers List<Carrier>?
일부 통신사만 노출 설정
final
carrier Carrier?
통신사 코드
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited