PaymentResponse class

리디렉션 없이 결제 UI가 표시된 경우 반환값

Constructors

PaymentResponse({required String transactionType, required String txId, required String paymentId, String? paymentToken, String? code, String? message, String? pgCode, String? pgMessage})

Properties

code String?
오류 코드
final
hashCode int
The hash code for this object.
no setterinherited
message String?
오류 메시지
final
paymentId String
결제 ID
final
paymentToken String?
결제 토큰
final
pgCode String?
PG 오류 코드
final
pgMessage String?
PG 오류 메시지
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionType String
유형
final
txId String
결제 시도 ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) PaymentResponse