Address class

주소 정보

Constructors

Address({Country? country, required String addressLine1, required String addressLine2, String? city, String? province})

Properties

addressLine1 → String
주소 첫째 줄
final
addressLine2 → String
주소 둘째 줄
final
city → String?
도시
final
country → Country?
국가
final
hashCode → int
The hash code for this object.
no setterinherited
province → String?
주, 도, 시
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited