IdentityVerificationBypass class
PG사 본인인증 창 호출 시 PG사로 그대로 bypass할 값들의 모음
Constructors
- IdentityVerificationBypass({DanalIdentityVerificationBypass? danal, InicisUnifiedIdentityVerificationBypass? inicisUnified, KcpV2IdentityVerificationBypass? kcpV2})
Properties
- danal → DanalIdentityVerificationBypass?
-
다날 bypass 파라미터
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inicisUnified → InicisUnifiedIdentityVerificationBypass?
-
KG이니시스 bypass 파라미터
final
- kcpV2 → KcpV2IdentityVerificationBypass?
-
KCP bypass 파라미터
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited