CardPromotion class
카드 프로모션 정보
카드사 다이렉트 호출 시 적용할 카드사 할인 쿠폰 정보입니다.
현재 KCP_V2 채널에서만 사용 가능합니다.
Constructors
- CardPromotion({required String promotionId, required int discountAmount})
Properties
- discountAmount → int
-
할인 금액
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- promotionId → String
-
프로모션 ID
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited