Customer class

Constructors

Customer({String? customerId, String? fullName, String? firstName, String? lastName, String? phoneNumber, String? email, Address? address, String? zipcode, Gender? gender, String? birthYear, String? birthMonth, String? birthDay, String? firstNameKana, String? lastNameKana})

Properties

address → Address?
주소 정보
final
birthDay → String?
구매자 출생일
final
birthMonth → String?
구매자 출생월
final
birthYear → String?
구매자 출생년도
final
customerId → String?
구매자 ID
final
email → String?
구매자 이메일 주소
final
firstName → String?
구매자 성이 아닌 이름
final
firstNameKana → String?
구매자 일본어 성이 아닌 이름 후리가나(읽는 법)
final
fullName → String?
구매자 전체 이름
final
gender → Gender?
구매자 성별
final
hashCode → int
The hash code for this object.
no setterinherited
lastName → String?
구매자 성
final
lastNameKana → String?
구매자 일본어 성 후리가나(읽는 법)
final
phoneNumber → String?
구매자 휴대전화 번호
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zipcode → String?
구매자 우편번호
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited