EasyPayPaymentMethod enum
간편결제 결제수단
Values
- CARD → const EasyPayPaymentMethod
-
카드
const EasyPayPaymentMethod('CARD') - CHARGE → const EasyPayPaymentMethod
-
포인트(충전, 적립) 결제
const EasyPayPaymentMethod('CHARGE') - TRANSFER → const EasyPayPaymentMethod
-
계좌결제
const EasyPayPaymentMethod('TRANSFER') - MONEY → const EasyPayPaymentMethod
-
포인트 및 계좌결제가 모두 가능한 경우
const EasyPayPaymentMethod('MONEY')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
EasyPayPaymentMethod> - A constant List of the values in this enum, in order of their declaration.