EasyPayProvider enum
PG 제휴로 간편결제를 이용할 때, 간편결제 UI를 직접 호출할 수 있는 간편결제
Values
- NAVERPAY → const EasyPayProvider
-
네이버페이
- 토스페이먼츠
- 나이스페이먼츠
- KG이니시스
- 스마트로
- NHN KCP
- KSNET
- 한국결제네트웍스
const EasyPayProvider('NAVERPAY') - KAKAOPAY → const EasyPayProvider
-
카카오페이
- 토스페이먼츠
- 나이스페이먼츠
- KG이니시스
- 스마트로
- NHN KCP
- KSNET
- 한국결제네트웍스
- 웰컴페이먼츠
const EasyPayProvider('KAKAOPAY') - TOSSPAY → const EasyPayProvider
-
토스페이
- 토스페이먼츠
- KG이니시스
- NHN KCP
- 스마트로
- 한국결제네트웍스
- 웰컴페이먼츠
const EasyPayProvider('TOSSPAY') - PAYCO → const EasyPayProvider
-
페이코
- 토스페이먼츠
- 나이스페이먼츠
- KG이니시스
- 스마트로
- KSNET
- 한국결제네트웍스
- 웰컴페이먼츠
const EasyPayProvider('PAYCO') - CHAI → const EasyPayProvider
-
차이페이
const EasyPayProvider('CHAI') - LPAY → const EasyPayProvider
-
L페이
- 토스페이먼츠
- 나이스페이먼츠
- KG이니시스
- 스마트로
- KSNET
- 웰컴페이먼츠
const EasyPayProvider('LPAY') - KPAY → const EasyPayProvider
-
K페이
const EasyPayProvider('KPAY') - SSGPAY → const EasyPayProvider
-
SSG페이
- 토스페이먼츠
- 나이스페이먼츠
- KG이니시스
- NHN KCP
- KSNET
const EasyPayProvider('SSGPAY') - SAMSUNGPAY → const EasyPayProvider
-
삼성페이
- 토스페이먼츠
- 나이스페이먼츠
- KG이니시스
- NHN KCP
- 스마트로
- 한국결제네트웍스
const EasyPayProvider('SAMSUNGPAY') - APPLEPAY → const EasyPayProvider
-
애플페이
- 토스페이먼츠
- 나이스페이먼츠
- KG이니시스
- NHN KCP
const EasyPayProvider('APPLEPAY') - LGPAY → const EasyPayProvider
-
LG페이
- 토스페이먼츠
const EasyPayProvider('LGPAY') - SKPAY → const EasyPayProvider
-
SK페이
- 나이스페이먼츠
const EasyPayProvider('SKPAY') - PINPAY → const EasyPayProvider
-
핀페이
- 스마트로
const EasyPayProvider('PINPAY') - TOSS_BRANDPAY → const EasyPayProvider
-
토스 브랜드페이
const EasyPayProvider('TOSS_BRANDPAY') - HYPHEN → const EasyPayProvider
-
하이픈
const EasyPayProvider('HYPHEN') - LINEPAY → const EasyPayProvider
-
라인페이
- 스마트로
const EasyPayProvider('LINEPAY') - TMONEY → const EasyPayProvider
-
티머니
- 스마트로
const EasyPayProvider('TMONEY') - PAYPAY → const EasyPayProvider
-
PayPay
- KG이니시스 JPPG/SBPS 일본결제
const EasyPayProvider('PAYPAY') - AMAZONPAY → const EasyPayProvider
-
아마존페이
- KG이니시스 JPPG 일본결제
const EasyPayProvider('AMAZONPAY') - RAKUTENPAY → const EasyPayProvider
-
라쿠텐페이
- KG이니시스 JPPG 일본결제
const EasyPayProvider('RAKUTENPAY') - DBARAI → const EasyPayProvider
-
dBarai
- KG이니시스 JPPG 일본결제
const EasyPayProvider('DBARAI') - AUPAY → const EasyPayProvider
-
auPAY
- KG이니시스 JPPG 일본결제
const EasyPayProvider('AUPAY') - MERPAY → const EasyPayProvider
-
Merpay
- KG이니시스 JPPG 일본결제
const EasyPayProvider('MERPAY')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
EasyPayProvider> - A constant List of the values in this enum, in order of their declaration.