InstallmentMonthOptionAvailableMonthList class
구매자가 선택할 수 있는 할부 개월수 리스트
구매자가 할부 개월 수를 선택할 수 없도록 하려면 fixedMonth를 사용해주세요.
- Inheritance
-
- Object
- InstallmentMonthOption
- InstallmentMonthOptionAvailableMonthList
Constructors
-
InstallmentMonthOptionAvailableMonthList(List<
int> ? availableMonthList)
Properties
-
availableMonthList
→ List<
int> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited