PaymentPayMethod enum
Values
- CARD → const PaymentPayMethod
-
카드
const PaymentPayMethod('CARD') - VIRTUAL_ACCOUNT → const PaymentPayMethod
-
가상계좌
const PaymentPayMethod('VIRTUAL_ACCOUNT') - TRANSFER → const PaymentPayMethod
-
계좌이체
const PaymentPayMethod('TRANSFER') - MOBILE → const PaymentPayMethod
-
휴대폰 소액결제
const PaymentPayMethod('MOBILE') - GIFT_CERTIFICATE → const PaymentPayMethod
-
상품권
const PaymentPayMethod('GIFT_CERTIFICATE') - EASY_PAY → const PaymentPayMethod
-
간편 결제
const PaymentPayMethod('EASY_PAY') - PAYPAL → const PaymentPayMethod
-
페이팔(SPB)
const PaymentPayMethod('PAYPAL') - ALIPAY → const PaymentPayMethod
-
알리페이
const PaymentPayMethod('ALIPAY') - CONVENIENCE_STORE → const PaymentPayMethod
-
편의점 결제
const PaymentPayMethod('CONVENIENCE_STORE')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PaymentPayMethod> - A constant List of the values in this enum, in order of their declaration.