Product class
구매 상품 상세 정보
Constructors
Properties
- amount → int
-
상품 단위 가격
final
- code → String?
-
상품 코드
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
상품 ID
final
- link → String?
-
상품 판매 URL
final
- name → String
-
상품명
final
- quantity → int
-
상품 수량
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
상품 태그
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited