StoreDetails class
상점 정보
- KSNET 카카오페이의 경우 필수 입력
- 나이스페이먼츠의 경우 매출 전표에 표기 할 용도로 선택 입력
- KG이니시스 일본결제의 경우 JPPG(gmoPayment) 결제의 상점정보로 사용되거나 편의점 결제 시 영수증 표시 정보로 사용됨.
Constructors
- StoreDetails({String? ceoFullName, String? phoneNumber, String? address, String? zipcode, String? email, String? businessName, String? businessRegistrationNumber, String? storeName, String? storeNameShort, String? storeNameEn, String? storeNameKana, StoreDetailsOpeningHours? openingHours, String? contactName})
Properties
- address → String?
-
주소
final
- businessName → String?
-
사업자명 (상호)
final
- businessRegistrationNumber → String?
-
사업자 등록 번호
final
- ceoFullName → String?
-
대표자 이름
final
- contactName → String?
-
상점 연락처 정보 이름
final
- email → String?
-
이메일
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- openingHours → StoreDetailsOpeningHours?
-
상점 영업시간 (HH:mm)
final
- phoneNumber → String?
-
전화번호
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storeName → String?
-
상점명
final
- storeNameEn → String?
-
상점명 영문
final
- storeNameKana → String?
-
상점명 후리카나 (일본어 읽는법 표기)
final
- storeNameShort → String?
-
상점명 약어
final
- zipcode → String?
-
우편번호
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited