PaymentRequest class

Constructors

PaymentRequest({required String storeId, required String paymentId, required String orderName, required int totalAmount, required Currency currency, required PaymentPayMethod payMethod, String? channelKey, String? channelGroupId, int? taxFreeAmount, int? vatAmount, Customer? customer, WindowTypes? windowType, bool? forceRedirect, List<String>? noticeUrls, String? confirmUrl, required String appScheme, bool? isEscrow, List<Product>? products, bool? isCulturalExpense, Locale? locale, Object? customData, Country? country, ProductType? productType, OfferPeriod? offerPeriod, StoreDetails? storeDetails, Address? shippingAddress, String? promotionId, Popup? popup, Iframe? iframe, PaymentBypass? bypass, PaymentRequestUnionCard? card, PaymentRequestUnionVirtualAccount? virtualAccount, PaymentRequestUnionTransfer? transfer, PaymentRequestUnionMobile? mobile, PaymentRequestUnionGiftCertificate? giftCertificate, PaymentRequestUnionEasyPay? easyPay, PaymentRequestUnionPaypal? paypal, PaymentRequestUnionAlipay? alipay, PaymentRequestUnionConvenienceStore? convenienceStore})

Properties

alipay PaymentRequestUnionAlipay?
final
appScheme String
모바일 결제 후 고객사 앱으로 복귀를 위한 URL scheme
final
bypass PaymentBypass?
PG사 결제창 호출 시 PG사로 그대로 bypass할 값들의 모음
final
card PaymentRequestUnionCard?
카드 결제 설정
final
channelGroupId String?
채널 그룹 ID
final
channelKey String?
채널 키
final
confirmUrl String?
결제 승인 여부 확인 URL
final
convenienceStore PaymentRequestUnionConvenienceStore?
final
country Country?
국가
final
currency Currency
화폐
final
customData Object?
결제 정보에 포함할 고객사 커스텀 JSON 데이터
final
customer Customer?
final
easyPay PaymentRequestUnionEasyPay?
final
forceRedirect bool?
결과 리턴 방식을 리디렉션으로 강제
final
giftCertificate PaymentRequestUnionGiftCertificate?
상품권 결제 설정
final
hashCode int
The hash code for this object.
no setterinherited
iframe Iframe?
결제창이 iframe 방식일 경우 결제창에 적용할 속성
final
isCulturalExpense bool?
문화비 지출 여부
final
isEscrow bool?
에스크로 결제 여부
final
locale Locale?
UI 언어
final
mobile PaymentRequestUnionMobile?
휴대전화 결제 설정
final
noticeUrls List<String>?
웹훅 수신 URL
final
offerPeriod OfferPeriod?
서비스 제공 기간
final
orderName String
주문명
final
paymentId String
결제 ID
final
payMethod PaymentPayMethod
결제수단 구분코드
final
paypal PaymentRequestUnionPaypal?
final
팝업 관련 필드
final
products List<Product>?
구매 상품 정보
final
productType ProductType?
상품 유형
final
promotionId String?
프로모션 아이디
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress Address?
주소 정보
final
storeDetails StoreDetails?
상점 정보
final
storeId String
상점 아이디
final
taxFreeAmount int?
면세 금액
final
totalAmount int
결제 금액
final
transfer PaymentRequestUnionTransfer?
계좌이체 결제 설정
final
vatAmount int?
부가세 금액
final
virtualAccount PaymentRequestUnionVirtualAccount?
가상계좌 결제 설정
final
windowType WindowTypes?
환경 별 제공되는 결제/본인인증 창 유형
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited