PaymentRequestUnionCard class
카드 결제 설정
Constructors
-
PaymentRequestUnionCard({CardCompany? cardCompany, List<
CardCompany> ? availableCards, bool? useFreeInterestFromMall, Installment? installment, bool? useCardPoint, bool? useAppCardOnly, bool? useInstallment, CardPromotion? cardPromotion})
Properties
-
availableCards
→ List<
CardCompany> ? -
일부 카드사만 노출 설정
final
- cardCompany → CardCompany?
-
카드 결제시 사용되는 카드사 코드
final
- cardPromotion → CardPromotion?
-
카드 프로모션 정보
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- installment → Installment?
-
할부 설정
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useAppCardOnly → bool?
-
앱 카드만 허용할지 여부
final
- useCardPoint → bool?
-
카드 포인트 사용 설정
final
- useFreeInterestFromMall → bool?
-
상점분담 무이자 활성화 여부
final
- useInstallment → bool?
-
할부 사용 가능 여부
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited