PaymentRequestUnionEasyPay class
Constructors
-
PaymentRequestUnionEasyPay({EasyPayProvider? easyPayProvider, bool? useFreeInterestFromMall, List<
CardCompany> ? availableCards, Installment? installment, CashReceiptType? cashReceiptType, String? customerIdentifier, bool? useCardPoint, List<EasyPayPaymentMethod> ? availablePayMethods, bool? useInstallment})
Properties
-
availableCards
→ List<
CardCompany> ? -
일부 카드사만 노출 설정
final
-
availablePayMethods
→ List<
EasyPayPaymentMethod> ? -
표시할 간편결제 수단 목록
final
- cashReceiptType → CashReceiptType?
-
현금영수증 발급 유형
final
- customerIdentifier → String?
-
현금영수증 구매자 번호
final
- easyPayProvider → EasyPayProvider?
-
PG 제휴로 간편결제를 이용할 때, 간편결제 UI를 직접 호출할 수 있는 간편결제
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- installment → Installment?
-
할부 설정
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useCardPoint → bool?
-
카드사 포인트 사용 여부
final
- useFreeInterestFromMall → bool?
-
상점분담 무이자 활성화 여부
final
- useInstallment → bool?
-
할부 사용 가능 여부
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited