PaymentRequestUnionVirtualAccount class

가상계좌 결제 설정

Constructors

PaymentRequestUnionVirtualAccount({CashReceiptType? cashReceiptType, String? customerIdentifier, PaymentRequestUnionVirtualAccountFixedOption? fixedOption, Bank? bankCode, PaymentRequestUnionVirtualAccountAccountExpiry? accountExpiry, List<Bank>? availableBanks})

Properties

accountExpiry → PaymentRequestUnionVirtualAccountAccountExpiry?
가상계좌 입금 만료 기한
final
availableBanks → List<Bank>?
선택 가능 은행 목록
final
bankCode → Bank?
가상계좌 발급시 사용되는 은행 코드
final
cashReceiptType → CashReceiptType?
현금영수증 발급 유형
final
customerIdentifier → String?
현금영수증 구매자 번호
final
fixedOption → PaymentRequestUnionVirtualAccountFixedOption?
고정식 가상계좌 설정
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited