IdentityVerificationResponse class

리디렉션 없이 결제 UI가 표시된 경우 반환값

Constructors

IdentityVerificationResponse({required String transactionType, required String identityVerificationId, required String identityVerificationTxId, String? code, String? message, String? pgCode, String? pgMessage})

Properties

code → String?
오류 코드
final
hashCode → int
The hash code for this object.
no setterinherited
identityVerificationId → String
본인인증 ID
final
identityVerificationTxId → String
본인인증 시도 ID
final
message → String?
오류 메시지
final
pgCode → String?
PG 오류 코드
final
pgMessage → String?
PG 오류 메시지
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionType → String
트랜잭션 유형
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → IdentityVerificationResponse