IssueBillingKeyResponse class
리디렉션 없이 빌링키 발급 UI가 표시된 경우 반환값
Constructors
Properties
- billingIssueToken → String?
-
수동 승인 사용시 수동 승인 API 호출에 필요한 토큰입니다.
final
- billingKey → String
-
빌링키
final
- code → String?
-
오류 코드
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
오류 메시지
final
- pgCode → String?
-
PG 오류 코드
final
- pgMessage → String?
-
PG 오류 메시지
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transactionType → String
-
ISSUE_BILLING_KEYfinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → IssueBillingKeyResponse